@@ -52,8 +52,8 @@ _nm_log_impl_cs (NMLogLevel level,
 	ts = nm_utils_clock_gettime_ns (CLOCK_BOOTTIME);
 
 	g_print ("[%"G_GINT64_FORMAT".%05"G_GINT64_FORMAT"] %s %s\n",
-	         ts / NM_UTILS_NS_PER_SECOND,
-	         (ts / (NM_UTILS_NS_PER_SECOND / 10000)) % 10000,
+	         ts / NM_UTILS_NSEC_PER_SEC,
+	         (ts / (NM_UTILS_NSEC_PER_SEC / 10000)) % 10000,
 	         level_str,
 	         msg);
 }
@@ -156,7 +156,7 @@ _wait_for_objects_iterate_until_done_idle_cb (gpointer user_data)
 /**
  * nmcs_wait_for_objects_iterate_until_done:
  * @context: the #GMainContext to iterate.
- * @timeout_ms: timeout or -1 for no timeout.
+ * @timeout_msec: timeout or -1 for no timeout.
  *
  * Iterates the provided @context until all objects that we wait for
  * are destroyed.
@@ -169,7 +169,7 @@ _wait_for_objects_iterate_until_done_idle_cb (gpointer user_data)
  */
 gboolean
 nmcs_wait_for_objects_iterate_until_done (GMainContext *context,
-                                          int timeout_ms)
+                                          int timeout_msec)
 {
 	nm_auto_unref_gmainloop GMainLoop *loop = g_main_loop_new (context, FALSE);
 	nm_auto_destroy_and_unref_gsource GSource *timeout_source = NULL;
@@ -189,8 +189,8 @@ nmcs_wait_for_objects_iterate_until_done (GMainContext *context,
 		.got_timeout = FALSE,
 	};
 
-	if (timeout_ms >= 0) {
-		timeout_source = nm_g_source_attach (nm_g_timeout_source_new (timeout_ms,
+	if (timeout_msec >= 0) {
+		timeout_source = nm_g_source_attach (nm_g_timeout_source_new (timeout_msec,
 		                                                              G_PRIORITY_DEFAULT,
 		                                                              _wait_for_objects_iterate_until_done_timeout_cb,
 		                                                              &data,
@@ -305,7 +305,7 @@ _poll_done_cb (GObject *source,
 		return;
 	}
 
-	now_ms = nm_utils_get_monotonic_timestamp_ms ();
+	now_ms = nm_utils_get_monotonic_timestamp_msec ();
 	if (poll_task_data->ratelimit_timeout_ms > 0)
 		wait_ms = (poll_task_data->last_poll_start_ms + poll_task_data->ratelimit_timeout_ms) - now_ms;
 	else
@@ -328,7 +328,7 @@ _poll_start_cb (gpointer user_data)
 
 	nm_clear_g_source_inst (&poll_task_data->source_next_poll);
 
-	poll_task_data->last_poll_start_ms = nm_utils_get_monotonic_timestamp_ms ();
+	poll_task_data->last_poll_start_ms = nm_utils_get_monotonic_timestamp_msec ();
 
 	g_object_ref (poll_task_data->task); /* balanced by _poll_done_cb() */
 
