@@ -30,12 +30,6 @@ gboolean nm_utils_g_param_spec_is_default (const GParamSpec *pspec);
 
 /*****************************************************************************/
 
-NMClientPermission nm_permission_to_client (const char *nm);
-
-NMClientPermissionResult nm_permission_result_to_client (const char *nm);
-
-/*****************************************************************************/
-
 typedef enum {
 	_NML_DBUS_LOG_LEVEL_INITIALIZED = 0x01,
 
@@ -185,6 +179,8 @@ typedef enum {
 
 /*****************************************************************************/
 
+#define NM_CLIENT_INSTANCE_FLAGS_ALL ((NMClientInstanceFlags) 0x1)
+
 typedef struct {
 	GType (*get_o_type_fcn) (void);
 
@@ -210,8 +206,6 @@ gpointer nml_dbus_property_o_get_obj (NMLDBusPropertyO *pr_o);
 
 gboolean nml_dbus_property_o_is_ready (const NMLDBusPropertyO *pr_o);
 
-gboolean nml_dbus_property_o_is_ready_fully (const NMLDBusPropertyO *pr_o);
-
 void nml_dbus_property_o_clear (NMLDBusPropertyO *pr_o,
                                 NMClient *client);
 
@@ -620,8 +614,7 @@ NML_IS_DBUS_OBJECT (NMLDBusObject *dbobj)
 	nm_assert (   !dbobj
 	           || (   NM_IS_REF_STRING (dbobj->dbus_path)
 	               && dbobj->ref_count > 0));
-	nm_assert (   !dbobj
-	           || !dbobj->nmobj
+	nm_assert (   !dbobj->nmobj
 	           || NM_IS_OBJECT (dbobj->nmobj)
 	           || NM_IS_CLIENT (dbobj->nmobj));
 	return !!dbobj;
