@@ -17,7 +17,7 @@
 #include "systemd/nm-sd.h"
 
 #define MAX_NEIGHBORS         4096
-#define MIN_UPDATE_INTERVAL_NS (2 * NM_UTILS_NS_PER_SECOND)
+#define MIN_UPDATE_INTERVAL_NS (2 * NM_UTILS_NSEC_PER_SEC)
 
 #define LLDP_MAC_NEAREST_BRIDGE          ((const struct ether_addr *) ((uint8_t[ETH_ALEN]) { 0x01, 0x80, 0xc2, 0x00, 0x00, 0x0e }))
 #define LLDP_MAC_NEAREST_NON_TPMR_BRIDGE ((const struct ether_addr *) ((uint8_t[ETH_ALEN]) { 0x01, 0x80, 0xc2, 0x00, 0x00, 0x03 }))
@@ -385,23 +385,6 @@ lldp_neighbor_equal (LldpNeighbor *a, LldpNeighbor *b)
 			if (!nm_streq (a->attrs[attr_id].v_string, b->attrs[attr_id].v_string))
 				return FALSE;
 			break;
-		case LLDP_ATTR_TYPE_VARDICT:
-			if (!g_variant_equal (a->attrs[attr_id].v_variant, b->attrs[attr_id].v_variant))
-				return FALSE;
-			break;
-		case LLDP_ATTR_TYPE_ARRAY_OF_VARDICTS: {
-			NMCListElem *itr_a, *itr_b;
-
-			if (c_list_length (&a->attrs[attr_id].v_variant_list) != c_list_length (&b->attrs[attr_id].v_variant_list))
-				return FALSE;
-			itr_b = c_list_first_entry (&b->attrs[attr_id].v_variant_list, NMCListElem, lst);
-			c_list_for_each_entry (itr_a, &a->attrs[attr_id].v_variant_list, lst) {
-				if (!g_variant_equal (itr_a->data, itr_b->data))
-					return FALSE;
-				itr_b = c_list_entry (&itr_b->lst, NMCListElem, lst);
-			}
-			break;
-		}
 		default:
 			nm_assert (a->attrs[attr_id].attr_type == LLDP_ATTR_TYPE_NONE);
 			break;
@@ -534,8 +517,7 @@ lldp_neighbor_new (sd_lldp_neighbor *neighbor_sd, GError **error)
 	case SD_LLDP_CHASSIS_SUBTYPE_INTERFACE_NAME:
 	case SD_LLDP_CHASSIS_SUBTYPE_LOCALLY_ASSIGNED:
 	case SD_LLDP_CHASSIS_SUBTYPE_CHASSIS_COMPONENT:
-		neigh->chassis_id =    nm_utils_buf_utf8safe_escape_cp (chassis_id, chassis_id_len, NM_UTILS_STR_UTF8_SAFE_FLAG_ESCAPE_CTRL | NM_UTILS_STR_UTF8_SAFE_FLAG_ESCAPE_NON_ASCII)
-		                    ?: g_new0 (char, 1);
+		neigh->chassis_id = g_strndup ((const char *) chassis_id, chassis_id_len);
 		break;
 	case SD_LLDP_CHASSIS_SUBTYPE_MAC_ADDRESS:
 		neigh->chassis_id = nm_utils_hwaddr_ntoa (chassis_id, chassis_id_len);
@@ -551,8 +533,7 @@ lldp_neighbor_new (sd_lldp_neighbor *neighbor_sd, GError **error)
 	case SD_LLDP_PORT_SUBTYPE_INTERFACE_NAME:
 	case SD_LLDP_PORT_SUBTYPE_LOCALLY_ASSIGNED:
 	case SD_LLDP_PORT_SUBTYPE_PORT_COMPONENT:
-		neigh->port_id =    nm_utils_buf_utf8safe_escape_cp (port_id, port_id_len, NM_UTILS_STR_UTF8_SAFE_FLAG_ESCAPE_CTRL | NM_UTILS_STR_UTF8_SAFE_FLAG_ESCAPE_NON_ASCII)
-		                 ?: g_new0 (char, 1);
+		neigh->port_id = strndup ((char *) port_id, port_id_len);
 		break;
 	case SD_LLDP_PORT_SUBTYPE_MAC_ADDRESS:
 		neigh->port_id = nm_utils_hwaddr_ntoa (port_id, port_id_len);
@@ -847,7 +828,7 @@ data_changed_timeout (gpointer user_data)
 	priv = NM_LLDP_LISTENER_GET_PRIVATE (self);
 
 	priv->ratelimit_id = 0;
-	priv->ratelimit_next = nm_utils_get_monotonic_timestamp_ns() + MIN_UPDATE_INTERVAL_NS;
+	priv->ratelimit_next = nm_utils_get_monotonic_timestamp_nsec() + MIN_UPDATE_INTERVAL_NS;
 	data_changed_notify (self, priv);
 	return G_SOURCE_REMOVE;
 }
@@ -858,13 +839,13 @@ data_changed_schedule (NMLldpListener *self)
 	NMLldpListenerPrivate *priv = NM_LLDP_LISTENER_GET_PRIVATE (self);
 	gint64 now;
 
-	now = nm_utils_get_monotonic_timestamp_ns ();
+	now = nm_utils_get_monotonic_timestamp_nsec ();
 	if (now >= priv->ratelimit_next) {
 		nm_clear_g_source (&priv->ratelimit_id);
 		priv->ratelimit_next = now + MIN_UPDATE_INTERVAL_NS;
 		data_changed_notify (self, priv);
 	} else if (!priv->ratelimit_id)
-		priv->ratelimit_id = g_timeout_add (NM_UTILS_NS_TO_MSEC_CEIL (priv->ratelimit_next - now), data_changed_timeout, self);
+		priv->ratelimit_id = g_timeout_add (NM_UTILS_NSEC_TO_MSEC_CEIL (priv->ratelimit_next - now), data_changed_timeout, self);
 }
 
 static void
