@@ -128,7 +128,6 @@ lease_option_next_route (struct in_addr *destp,
 	uint8_t *data = *datap;
 	size_t n_data = *n_datap;
 	uint8_t plen;
-	uint8_t bytes;
 
 	if (classless) {
 		if (!lease_option_consume (&plen, sizeof (plen), &data, &n_data))
@@ -137,9 +136,7 @@ lease_option_next_route (struct in_addr *destp,
 		if (plen > 32)
 			return FALSE;
 
-		bytes = plen == 0 ? 0 : ((plen - 1) / 8) + 1;
-
-		if (!lease_option_consume (&dest, bytes, &data, &n_data))
+		if (!lease_option_consume (&dest, plen / 8, &data, &n_data))
 			return FALSE;
 	} else {
 		if (!lease_option_next_in_addr (&dest, &data, &n_data))
@@ -249,10 +246,10 @@ lease_option_print_domain_name (GString *str, uint8_t *cache, size_t *n_cachep,
 				return TRUE;
 			}
 
-			if (!first)
+			if (!first) {
 				g_string_append_c(str, '.');
-			else
 				first = FALSE;
+			}
 
 			if (!lease_option_print_label (str, n_label, domainp, n_domainp))
 				return FALSE;
@@ -376,8 +373,8 @@ lease_parse_address (NDhcp4ClientLease *lease,
 		 * Here we still do it... it seems safe enough. */
 		nm_assert (nettools_basetime > 0);
 		nm_assert (nettools_lifetime >= nettools_basetime);
-		nm_assert (((nettools_lifetime - nettools_basetime) % NM_UTILS_NS_PER_SECOND) == 0);
-		nm_assert ((nettools_lifetime - nettools_basetime) / NM_UTILS_NS_PER_SECOND <= G_MAXUINT32);
+		nm_assert (((nettools_lifetime - nettools_basetime) % NM_UTILS_NSEC_PER_SEC) == 0);
+		nm_assert ((nettools_lifetime - nettools_basetime) / NM_UTILS_NSEC_PER_SEC <= G_MAXUINT32);
 
 		if (nettools_lifetime <= nettools_basetime) {
 			/* A lease time of 0 is allowed on some dhcp servers, so, let's accept it. */
@@ -387,7 +384,7 @@ lease_parse_address (NDhcp4ClientLease *lease,
 
 			/* we "ceil" the value to the next second. In practice, we don't expect any sub-second values
 			 * from n-dhcp4 anyway, so this should have no effect. */
-			lifetime += NM_UTILS_NS_PER_SECOND - 1;
+			lifetime += NM_UTILS_NSEC_PER_SEC - 1;
 		}
 
 		ts = nm_utils_monotonic_timestamp_from_boottime (nettools_basetime, 1);
@@ -395,11 +392,11 @@ lease_parse_address (NDhcp4ClientLease *lease,
 		/* the timestamp must be positive, because we only started nettools DHCP client
 		 * after obtaining the first monotonic timestamp. Hence, the lease must have been
 		 * received afterwards. */
-		nm_assert (ts >= NM_UTILS_NS_PER_SECOND);
+		nm_assert (ts >= NM_UTILS_NSEC_PER_SEC);
 
-		a_timestamp = ts / NM_UTILS_NS_PER_SECOND;
-		a_lifetime = NM_MIN (lifetime / NM_UTILS_NS_PER_SECOND, NM_PLATFORM_LIFETIME_PERMANENT - 1);
-		a_expiry = time (NULL) + ((lifetime - (nm_utils_clock_gettime_ns (CLOCK_BOOTTIME) - nettools_basetime)) / NM_UTILS_NS_PER_SECOND);
+		a_timestamp = ts / NM_UTILS_NSEC_PER_SEC;
+		a_lifetime = NM_MIN (lifetime / NM_UTILS_NSEC_PER_SEC, NM_PLATFORM_LIFETIME_PERMANENT - 1);
+		a_expiry = time (NULL) + ((lifetime - (nm_utils_clock_gettime_ns (CLOCK_BOOTTIME) - nettools_basetime)) / NM_UTILS_NSEC_PER_SEC);
 	}
 
 	if (!lease_get_in_addr (lease, NM_DHCP_OPTION_DHCP4_SUBNET_MASK, &a_netmask)) {
@@ -778,12 +775,23 @@ lease_parse_domainname (NDhcp4ClientLease *lease,
 	                           str->str);
 }
 
-char **
-nm_dhcp_parse_search_list (guint8 *data, size_t n_data)
+static void
+lease_parse_search_domains (NDhcp4ClientLease *lease,
+                            NMIP4Config *ip4_config,
+                            GHashTable *options)
 {
-	GPtrArray *array = NULL;
-	guint8 *cache = data;
-	size_t n_cache = 0;
+	nm_auto_free_gstring GString *str = NULL;
+	uint8_t *data, *cache;
+	size_t n_data, n_cache = 0;
+	int r;
+
+	r = n_dhcp4_client_lease_query (lease, NM_DHCP_OPTION_DHCP4_DOMAIN_SEARCH_LIST, &data, &n_data);
+	if (r)
+		return;
+
+	cache = data;
+
+	nm_gstring_prepare (&str);
 
 	for (;;) {
 		nm_auto_free_gstring GString *domain = NULL;
@@ -793,42 +801,8 @@ nm_dhcp_parse_search_list (guint8 *data, size_t n_data)
 		if (!lease_option_print_domain_name (domain, cache, &n_cache, &data, &n_data))
 			break;
 
-		if (!array)
-			array = g_ptr_array_new ();
-
-		g_ptr_array_add (array, g_string_free (domain, FALSE));
-		domain = NULL;
-	}
-
-	if (array) {
-		g_ptr_array_add (array, NULL);
-		return (char **) g_ptr_array_free (array, FALSE);
-	} else
-		return NULL;
-}
-
-static void
-lease_parse_search_domains (NDhcp4ClientLease *lease,
-                            NMIP4Config *ip4_config,
-                            GHashTable *options)
-{
-	nm_auto_free_gstring GString *str = NULL;
-	uint8_t *data;
-	size_t n_data;
-	gs_strfreev char **domains = NULL;
-	guint i;
-	int r;
-
-	r = n_dhcp4_client_lease_query (lease, NM_DHCP_OPTION_DHCP4_DOMAIN_SEARCH_LIST, &data, &n_data);
-	if (r)
-		return;
-
-	domains = nm_dhcp_parse_search_list (data, n_data);
-	nm_gstring_prepare (&str);
-
-	for (i = 0; domains && domains[i]; i++) {
-		g_string_append (nm_gstring_add_space_delimiter (str), domains[i]);
-		nm_ip4_config_add_search (ip4_config, domains[i]);
+		g_string_append (nm_gstring_add_space_delimiter (str), domain->str);
+		nm_ip4_config_add_search (ip4_config, domain->str);
 	}
 	nm_dhcp_option_add_option (options,
 	                           _nm_dhcp_option_dhcp4_options,
@@ -950,12 +924,11 @@ lease_to_ip4_config (NMDedupMultiIndex *multi_idx,
 /*****************************************************************************/
 
 static void
-lease_save (NMDhcpNettools *self, NDhcp4ClientLease *lease, const char *lease_file)
+lease_save (NDhcp4ClientLease *lease, const char *lease_file)
 {
 	struct in_addr a_address;
 	nm_auto_free_gstring GString *new_contents = NULL;
 	char sbuf[NM_UTILS_INET_ADDRSTRLEN];
-	gs_free_error GError *error = NULL;
 
 	nm_assert (lease);
 	nm_assert (lease_file);
@@ -969,15 +942,14 @@ lease_save (NMDhcpNettools *self, NDhcp4ClientLease *lease, const char *lease_fi
 	g_string_append_printf (new_contents,
 	                        "ADDRESS=%s\n", nm_utils_inet4_ntop (a_address.s_addr, sbuf));
 
-	if (!g_file_set_contents (lease_file,
-	                          new_contents->str,
-	                          -1,
-	                          &error))
-		_LOGW ("error saving lease to %s: %s", lease_file, error->message);
+	g_file_set_contents (lease_file,
+	                     new_contents->str,
+	                     -1,
+	                     NULL);
 }
 
 static void
-bound4_handle (NMDhcpNettools *self, NDhcp4ClientLease *lease, gboolean extended)
+bound4_handle (NMDhcpNettools *self, NDhcp4ClientLease *lease)
 {
 	NMDhcpNettoolsPrivate *priv = NM_DHCP_NETTOOLS_GET_PRIVATE (self);
 	const char *iface = nm_dhcp_client_get_iface (NM_DHCP_CLIENT (self));
@@ -985,7 +957,7 @@ bound4_handle (NMDhcpNettools *self, NDhcp4ClientLease *lease, gboolean extended
 	gs_unref_hashtable GHashTable *options = NULL;
 	GError *error = NULL;
 
-	_LOGT ("lease available (%s)", extended ? "extended" : "new");
+	_LOGT ("lease available");
 
 	ip4_config = lease_to_ip4_config (nm_dhcp_client_get_multi_idx (NM_DHCP_CLIENT (self)),
 	                                  iface,
@@ -1003,10 +975,10 @@ bound4_handle (NMDhcpNettools *self, NDhcp4ClientLease *lease, gboolean extended
 	}
 
 	nm_dhcp_option_add_requests_to_options (options, _nm_dhcp_option_dhcp4_options);
-	lease_save (self, lease, priv->lease_file);
+	lease_save (lease, priv->lease_file);
 
 	nm_dhcp_client_set_state (NM_DHCP_CLIENT (self),
-	                          extended ? NM_DHCP_STATE_EXTENDED : NM_DHCP_STATE_BOUND,
+	                          NM_DHCP_STATE_BOUND,
 	                          NM_IP_CONFIG_CAST (ip4_config),
 	                          options);
 }
@@ -1028,19 +1000,19 @@ dhcp4_event_handle (NMDhcpNettools *self,
 			_LOGW ("selecting lease failed: %d", r);
 		}
 		break;
-	case N_DHCP4_CLIENT_EVENT_RETRACTED:
 	case N_DHCP4_CLIENT_EVENT_EXPIRED:
 		nm_dhcp_client_set_state (NM_DHCP_CLIENT (self), NM_DHCP_STATE_EXPIRE, NULL, NULL);
 		break;
+	case N_DHCP4_CLIENT_EVENT_RETRACTED:
 	case N_DHCP4_CLIENT_EVENT_CANCELLED:
 		nm_dhcp_client_set_state (NM_DHCP_CLIENT (self), NM_DHCP_STATE_FAIL, NULL, NULL);
 		break;
 	case N_DHCP4_CLIENT_EVENT_GRANTED:
 		priv->lease = n_dhcp4_client_lease_ref (event->granted.lease);
-		bound4_handle (self, event->granted.lease, FALSE);
+		bound4_handle (self, event->granted.lease);
 		break;
 	case N_DHCP4_CLIENT_EVENT_EXTENDED:
-		bound4_handle (self, event->extended.lease, TRUE);
+		bound4_handle (self, event->extended.lease);
 		break;
 	case N_DHCP4_CLIENT_EVENT_DOWN:
 		/* ignore down events, they are purely informational */
@@ -1064,18 +1036,8 @@ dhcp4_event_cb (GIOChannel *source,
 	int r;
 
 	r = n_dhcp4_client_dispatch (priv->client);
-	if (r < 0) {
-		/* FIXME: if any operation (e.g. send()) fails during the
-		 * dispatch, n-dhcp4 returns an error without arming timers
-		 * or progressing state, so the only reasonable thing to do
-		 * is to move to failed state so that the client will be
-		 * restarted. Ideally n-dhcp4 should retry failed operations
-		 * a predefined number of times (possibly infinite).
-		 */
-		_LOGE ("error %d dispatching events", r);
-		nm_dhcp_client_set_state (NM_DHCP_CLIENT (self), NM_DHCP_STATE_FAIL, NULL, NULL);
-		return G_SOURCE_REMOVE;
-	}
+	if (r < 0)
+		return G_SOURCE_CONTINUE;
 
 	while (!n_dhcp4_client_pop_event (priv->client, &event) && event) {
 		dhcp4_event_handle (self, event);
@@ -1321,10 +1283,8 @@ ip4_start (NMDhcpClient *client,
 			sd_dhcp_lease_get_address (lease, &last_addr);
 	}
 
-	if (last_addr.s_addr) {
+	if (last_addr.s_addr)
 		n_dhcp4_client_probe_config_set_requested_ip (config, last_addr);
-		n_dhcp4_client_probe_config_set_init_reboot (config, TRUE);
-	}
 
 	/* Add requested options */
 	for (i = 0; _nm_dhcp_option_dhcp4_options[i].name; i++) {
