@@ -7,16 +7,23 @@
 #define NM_AUTH_MANAGER_H
 
 #include "nm-auth-subject.h"
+#include "nm-config-data.h"
 
 /*****************************************************************************/
 
 typedef enum {
-	NM_AUTH_CALL_RESULT_UNKNOWN,
-	NM_AUTH_CALL_RESULT_YES,
-	NM_AUTH_CALL_RESULT_AUTH,
-	NM_AUTH_CALL_RESULT_NO,
+	NM_AUTH_CALL_RESULT_UNKNOWN = NM_CLIENT_PERMISSION_RESULT_UNKNOWN,
+	NM_AUTH_CALL_RESULT_YES     = NM_CLIENT_PERMISSION_RESULT_YES,
+	NM_AUTH_CALL_RESULT_AUTH    = NM_CLIENT_PERMISSION_RESULT_AUTH,
+	NM_AUTH_CALL_RESULT_NO      = NM_CLIENT_PERMISSION_RESULT_NO,
 } NMAuthCallResult;
 
+static inline NMClientPermissionResult
+nm_auth_call_result_to_client (NMAuthCallResult result)
+{
+	return (NMClientPermissionResult) result;
+}
+
 static inline NMAuthCallResult
 nm_auth_call_result_eval (gboolean is_authorized,
                           gboolean is_challenge,
@@ -49,7 +56,7 @@ typedef struct _NMAuthManagerClass NMAuthManagerClass;
 
 GType nm_auth_manager_get_type (void);
 
-NMAuthManager *nm_auth_manager_setup (gboolean polkit_enabled);
+NMAuthManager *nm_auth_manager_setup (NMAuthPolkitMode auth_polkit_mode);
 NMAuthManager *nm_auth_manager_get (void);
 
 void nm_auth_manager_force_shutdown (NMAuthManager *self);
