@@ -195,7 +195,7 @@ static void
 expire_ip6_delegations (NMPolicy *self)
 {
 	NMPolicyPrivate *priv = NM_POLICY_GET_PRIVATE (self);
-	guint32 now = nm_utils_get_monotonic_timestamp_s ();
+	guint32 now = nm_utils_get_monotonic_timestamp_sec ();
 	IP6PrefixDelegation *delegation = NULL;
 	guint i;
 
@@ -1006,6 +1006,21 @@ update_ip4_routing (NMPolicy *self, gboolean force_update)
 	_notify (self, PROP_DEFAULT_IP4_AC);
 }
 
+static void
+update_ip6_dns_delegation (NMPolicy *self)
+{
+	NMPolicyPrivate *priv = NM_POLICY_GET_PRIVATE (self);
+	NMDevice *device;
+	NMActiveConnection *ac;
+	const CList *tmp_list;
+
+	nm_manager_for_each_active_connection (priv->manager, ac, tmp_list) {
+		device = nm_active_connection_get_device (ac);
+		if (device && nm_device_needs_ip6_subnet (device))
+			nm_device_copy_ip6_dns_config (device, get_default_device (self, AF_INET6));
+	}
+}
+
 static void
 update_ip6_prefix_delegation (NMPolicy *self)
 {
@@ -1074,9 +1089,8 @@ update_ip6_routing (NMPolicy *self, gboolean force_update)
 }
 
 static void
-update_ip_dns (NMPolicy *self, int addr_family, NMDevice *changed_device)
+update_ip_dns (NMPolicy *self, int addr_family)
 {
-	NMPolicyPrivate *priv = NM_POLICY_GET_PRIVATE (self);
 	gpointer ip_config;
 	const char *ip_iface = NULL;
 	NMVpnConnection *vpn = NULL;
@@ -1097,32 +1111,19 @@ update_ip_dns (NMPolicy *self, int addr_family, NMDevice *changed_device)
 		                            device);
 	}
 
-	if (addr_family == AF_INET6) {
-		NMActiveConnection *ac;
-		const CList *tmp_list;
-
-		/* Tell devices needing a subnet about the new DNS configuration */
-		nm_manager_for_each_active_connection (priv->manager, ac, tmp_list) {
-			device = nm_active_connection_get_device (ac);
-			if (   device
-			    && device != changed_device
-			    && nm_device_needs_ip6_subnet (device))
-				nm_device_copy_ip6_dns_config (device, get_default_device (self, AF_INET6));
-		}
-	}
+	if (addr_family == AF_INET6)
+		update_ip6_dns_delegation (self);
 }
 
 static void
-update_routing_and_dns (NMPolicy *self,
-                        gboolean force_update,
-                        NMDevice *changed_device)
+update_routing_and_dns (NMPolicy *self, gboolean force_update)
 {
 	NMPolicyPrivate *priv = NM_POLICY_GET_PRIVATE (self);
 
 	nm_dns_manager_begin_updates (priv->dns_manager, __func__);
 
-	update_ip_dns (self, AF_INET, changed_device);
-	update_ip_dns (self, AF_INET6, changed_device);
+	update_ip_dns (self, AF_INET);
+	update_ip_dns (self, AF_INET6);
 
 	update_ip4_routing (self, force_update);
 	update_ip6_routing (self, force_update);
@@ -1548,7 +1549,7 @@ reset_connections_retries (gpointer user_data)
 	priv->reset_retries_id = 0;
 
 	min_stamp = 0;
-	now = nm_utils_get_monotonic_timestamp_s ();
+	now = nm_utils_get_monotonic_timestamp_sec ();
 	connections = nm_settings_get_connections (priv->settings, NULL);
 	for (i = 0; connections[i]; i++) {
 		NMSettingsConnection *connection = connections[i];
@@ -1593,7 +1594,7 @@ _connection_autoconnect_retries_set (NMPolicy *self,
 			gint32 retry_time = nm_settings_connection_autoconnect_retries_blocked_until (connection);
 
 			g_warn_if_fail (retry_time != 0);
-			priv->reset_retries_id = g_timeout_add_seconds (MAX (0, retry_time - nm_utils_get_monotonic_timestamp_s ()), reset_connections_retries, self);
+			priv->reset_retries_id = g_timeout_add_seconds (MAX (0, retry_time - nm_utils_get_monotonic_timestamp_sec ()), reset_connections_retries, self);
 		}
 	}
 }
@@ -1791,7 +1792,7 @@ device_state_changed (NMDevice *device,
 		if (   sett_conn
 		    && old_state >= NM_DEVICE_STATE_PREPARE
 		    && old_state <= NM_DEVICE_STATE_ACTIVATED) {
-			gboolean blocked = FALSE;
+			gboolean block_no_secrets = FALSE;
 			int tries;
 			guint64 con_v;
 
@@ -1811,32 +1812,15 @@ device_state_changed (NMDevice *device,
 				 */
 				con_v = nm_settings_connection_get_last_secret_agent_version_id (sett_conn);
 				if (   con_v == 0
-				    || con_v == nm_agent_manager_get_agent_version_id (priv->agent_mgr)) {
-					_LOGD (LOGD_DEVICE, "connection '%s' now blocked from autoconnect due to no secrets",
-					       nm_settings_connection_get_id (sett_conn));
-					nm_settings_connection_autoconnect_blocked_reason_set (sett_conn,
-					                                                       NM_SETTINGS_AUTO_CONNECT_BLOCKED_REASON_NO_SECRETS,
-					                                                       TRUE);
-					blocked = TRUE;
-				}
-			} else if (nm_device_state_reason_check (reason) == NM_DEVICE_STATE_REASON_DEPENDENCY_FAILED) {
-				/* A connection that fails due to dependency-failed is not
-				 * able to reconnect until the master connection activates
-				 * again; when this happens, the master clears the blocked
-				 * reason for all its slaves in activate_slave_connections()
-				 * and tries to reconnect them. For this to work, the slave
-				 * should be marked as blocked when it fails with
-				 * dependency-failed.
-				 */
-				_LOGD (LOGD_DEVICE, "connection '%s' now blocked from autoconnect due to failed dependency",
-				       nm_settings_connection_get_id (sett_conn));
-				nm_settings_connection_autoconnect_blocked_reason_set (sett_conn,
-				                                                       NM_SETTINGS_AUTO_CONNECT_BLOCKED_REASON_FAILED,
-				                                                       TRUE);
-				blocked = TRUE;
+				    || con_v == nm_agent_manager_get_agent_version_id (priv->agent_mgr))
+					block_no_secrets = TRUE;
 			}
 
-			if (!blocked) {
+			if (block_no_secrets) {
+				_LOGD (LOGD_DEVICE, "connection '%s' now blocked from autoconnect due to no secrets",
+				       nm_settings_connection_get_id (sett_conn));
+				nm_settings_connection_autoconnect_blocked_reason_set (sett_conn, NM_SETTINGS_AUTO_CONNECT_BLOCKED_REASON_NO_SECRETS, TRUE);
+			} else {
 				tries = nm_settings_connection_autoconnect_retries_get (sett_conn);
 				if (tries > 0) {
 					_LOGD (LOGD_DEVICE, "connection '%s' failed to autoconnect; %d tries left",
@@ -1873,14 +1857,14 @@ device_state_changed (NMDevice *device,
 		if (ip6_config)
 			_dns_manager_set_ip_config (priv->dns_manager, NM_IP_CONFIG_CAST (ip6_config), NM_DNS_IP_CONFIG_TYPE_DEFAULT, device);
 
-		update_routing_and_dns (self, FALSE, device);
+		update_routing_and_dns (self, FALSE);
 
 		nm_dns_manager_end_updates (priv->dns_manager, __func__);
 		break;
 	case NM_DEVICE_STATE_UNMANAGED:
 	case NM_DEVICE_STATE_UNAVAILABLE:
 		if (old_state > NM_DEVICE_STATE_DISCONNECTED)
-			update_routing_and_dns (self, FALSE, device);
+			update_routing_and_dns (self, FALSE);
 		break;
 	case NM_DEVICE_STATE_DEACTIVATING:
 		if (sett_conn) {
@@ -1915,7 +1899,7 @@ device_state_changed (NMDevice *device,
 			reset_autoconnect_all (self, device, FALSE);
 
 		if (old_state > NM_DEVICE_STATE_DISCONNECTED)
-			update_routing_and_dns (self, FALSE, device);
+			update_routing_and_dns (self, FALSE);
 
 		/* Device is now available for auto-activation */
 		schedule_activate_check (self, device);
@@ -1946,7 +1930,7 @@ device_state_changed (NMDevice *device,
 		if (   s_con
 		    && nm_setting_connection_get_num_secondaries (s_con) > 0) {
 			/* Make routes and DNS up-to-date before activating dependent connections */
-			update_routing_and_dns (self, FALSE, device);
+			update_routing_and_dns (self, FALSE);
 
 			/* Activate secondary (VPN) connections */
 			if (!activate_secondary_connections (self,
@@ -2002,7 +1986,7 @@ device_ip_config_changed (NMDevice *device,
 			if (old_config)
 				nm_dns_manager_set_ip_config (priv->dns_manager, old_config, NM_DNS_IP_CONFIG_TYPE_REMOVED);
 		}
-		update_ip_dns (self, addr_family, device);
+		update_ip_dns (self, addr_family);
 		if (addr_family == AF_INET)
 			update_ip4_routing (self, TRUE);
 		else
@@ -2124,7 +2108,7 @@ vpn_connection_activated (NMPolicy *self, NMVpnConnection *vpn)
 	if (ip6_config)
 		nm_dns_manager_set_ip_config (priv->dns_manager, NM_IP_CONFIG_CAST (ip6_config), NM_DNS_IP_CONFIG_TYPE_VPN);
 
-	update_routing_and_dns (self, TRUE, NULL);
+	update_routing_and_dns (self, TRUE);
 
 	nm_dns_manager_end_updates (priv->dns_manager, __func__);
 }
@@ -2146,7 +2130,7 @@ vpn_connection_deactivated (NMPolicy *self, NMVpnConnection *vpn)
 	if (ip6_config)
 		nm_dns_manager_set_ip_config (priv->dns_manager, NM_IP_CONFIG_CAST (ip6_config), NM_DNS_IP_CONFIG_TYPE_REMOVED);
 
-	update_routing_and_dns (self, TRUE, NULL);
+	update_routing_and_dns (self, TRUE);
 
 	nm_dns_manager_end_updates (priv->dns_manager, __func__);
 }
